import lodash from 'lodash'
import { interact, replaceApiParams } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    contents: {}
  },
  mutations: {
    updateList (state, payload) {
      state.contents = payload || {}
    },
    appendList (state, payload) {
      const records = state.contents.records || []
      state.contents = {...state.contents, records: [...records, payload]}
    }
  },
  actions: {
    getContentList ({ commit }, payload) {
      const api = lodash.get(apis, 'content.list')
      interact(api, payload).then((data) => {
        commit('updateList', data)
      })
    },
    addContent ({ commit }, payload) {
      const { onSuccess } = payload
      const api = lodash.get(apis, 'content.add')
      interact(api, payload.detail).then((data) => {
        commit('appendList', data)
        if (onSuccess) {
          onSuccess(data)
        }
      })
    },
    deleteContent ( _, payload) {
      return new Promise((resolve, reject) => {
        const api = replaceApiParams(lodash.get(apis, 'content.delete'), payload)
        interact(api).then((data) => {
          resolve(data)
        }).catch(() => {
          reject()
        })
      })
    }
  }
}
