import lodash from 'lodash'
import { interact } from '../../utils'
import apis from '../../config/api'

export default {
  namespaced: true,
  state: {
    devices: {},
    snapshots: {},
  },
  mutations: {
    updateList (state, payload) {
      state.devices = payload
    },
    updateState (state, payload = {}) {
      Object.keys(payload).forEach((key) => {
        const val = payload[key]
        state[key] = Array.isArray(val) ? [ ...val ] : { ...val }
      })
    },
  },
  actions: {
    getDeviceList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'device.list')
        interact(api, payload).then((data) => {
          commit('updateList', data)
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    getSnapshots ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        const api = lodash.get(apis, 'device.snapshot')
        interact(api, payload).then((data) => {
          commit('updateState', { snapshots: data })
          resolve(data)
        }).catch(({ message }) => {
          if (typeof message === 'string') {
            reject(message)
          }
        })
      })
    },
    dispatchBatch (ctx, payload) {
      const api = lodash.get(apis, 'device.dispatch')
      return interact({ ...api, params: payload })
    }
  }
}