
const pages = [  
  {
    path: 'dashboard',
    name: 'dashboard',
    component: () => import('./Dashboard.vue'),
    meta: {
      menuShow: true,
      title: 'Dashboard',
    }
  },
  {
    path: 'system',
    name: 'system',
    component: () => import('./index.vue'),
    meta: {
      menuShow: true,
      title: '系统配置',
    },
    children: [
      {
        path: 'sysuser',
        name: 'sysuserlist',
        component: () => import('./sysuser/list.vue'),
        meta: {
          menuShow: true,
          title: '系统人员',
        },
      },
      {
        path: 'device',
        name: 'devicelist',
        component: () => import('./device/list.vue'),
        meta: {
          menuShow: true,
          title: '设备管理',
        },
      },
      {
        path: 'snapshot/:device',
        name: 'snapshotlist',
        component: () => import('./device/snapshot.vue'),
        meta: {
          menuShow: false,
          title: '抓拍列表',
        },
      },
      {
        path: 'paramlist',
        name: 'paramlist',
        component: () => import('./sysparam/list.vue'),
        meta: {
          menuShow: true,
          title: '系统参数配置',
        },
      },
      {
        path: 'paramedit',
        name: 'paramedit',
        component: () => import('./sysparam/edit.vue'),
        meta: {
          menuShow: false,
          title: '系统参数配置',
        },
      },
      {
        path: 'typelist',
        name: 'typelist',
        component: () => import('./type/list.vue'),
        meta: {
          menuShow: true,
          title: '人员类型',
        },
      },
      {
        path: 'sysuser/edit',
        name: 'sysuseredit',
        component: () => import('./sysuser/edit.vue'),
        meta: {
          menuShow: false,
          title: '销售管理',
        },
      },
     {
        path: 'typeedit',
        name: 'typeedit',
        component: () => import('./type/edit.vue'),
        meta: {
          menuShow: false,
          title: '人员类型编辑',
        }
      },
      {
        path: 'wordslist',
        name: 'wordslist',
        component: () => import('./words/list.vue'),
        meta: {
          menuShow: true,
          title: '来访致辞',
        },
      },
      {
        path: 'wordsedit',
        name: 'wordsedit',
        component: () => import('./words/edit.vue'),
        meta: {
          menuShow: false,
          title: '来访致辞编辑',
        },
      },
    ]
  },
  {
    path: 'person',
    name: 'personlist',
    component: () => import('./person/list.vue'),
    meta: {
      menuShow: true,
      title: '人员列表',
    },
  },
  {
    path: 'person/edit',
    name: 'personedit',
    component: () => import('./person/edit.vue'),
    meta: {
      menuShow: false,
      title: '人员编辑',
    },
  },
  {
    path: 'first',
    name: 'first',
    component: () => import('./index.vue'),
    meta: {
      menuShow: true,
      title: '首页配置',
    },
    children: [
      {
        path: 'content',
        name: 'content',
        component: () => import('./content/list.vue'),
        meta: {
          menuShow: true,
          title: '素 材 库',
        },
      },
      {
        path: 'noticelist',
        name: 'noticelist',
        component: () => import('./notice/list.vue'),
        meta: {
          menuShow: true,
          title: '公告设置',
        },
      },
      {
        path: 'noticeedit',
        name: 'noticeedit',
        component: () => import('./notice/edit.vue'),
        meta: {
          menuShow: false,
          title: '公告编辑',
        },
      },
      {
        path: 'screenlist',
        name: 'screenlist',
        component: () => import('./screen/list.vue'),
        meta: {
          menuShow: true,
          title: '首屏显示',
        },
      },
      {
        path: 'screenedit',
        name: 'screenedit',
        component: () => import('./screen/edit.vue'),
        meta: {
          menuShow: false,
          title: '首屏显示编辑',
        },
      },
    ],
  },
]

const flatten = (rts, parents = []) => {
  return rts.reduce((acc, rt) => {
    const chs = rt.children && rt.children.length ?
      flatten(rt.children, parents.concat(rt)) : []
    
    return [...acc, { ...rt, parents }, ...chs]
  }, [])
}

const pageArray = flatten(pages)

export { pages, pageArray }
